package org.vendor.tftp.common;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import org.vendor.tftp.common.TFTPOption;

public class OptionAck {
  public static final int OPCODE_INDEX = 0;
  
  public static final int OPCODE = 6;
  
  public static final int TIMEOUT = 5;
  
  public static final int LENGTH = 2;
  
  private int blockNr;
  
  private TFTPOption option;
  
  public int getBlockNr() {
    if (this.option.getBlkSize() % this.option.getBlkSize() > 0) {
      this.blockNr = this.option.gettSize() / this.option.getBlkSize();
    } else {
      this.blockNr = this.option.gettSize() / this.option.getBlkSize() + 1;
    } 
    return this.blockNr;
  }
  
  public OptionAck(TFTPOption options) {
    this.option = options;
  }
  
  private int getLength() {
    int length = 4;
    if (this.option == null)
      return length; 
    int tsize = this.option.gettSize();
    if (tsize > 0)
      length += "tsize".length() + 
        String.valueOf(tsize).length() + 2; 
    int timeout = this.option.getTimeOut();
    if (timeout > 0)
      length += "timeout".length() + 
        String.valueOf(timeout).length() + 2; 
    int blockSize = this.option.getBlkSize();
    if (blockSize > 0)
      length += "blksize".length() + 
        String.valueOf(blockSize).length() + 2; 
    return length;
  }
  
  public byte[] getAcknowledgementData() {
    byte[] data = new byte[4];
    data[0] = 0;
    data[1] = 4;
    data[2] = (byte)((getBlockNr() & 0xFFFF) >> 8);
    data[3] = (byte)(getBlockNr() & 0xFF);
    return data;
  }
  
  public byte[] getBytes() {
    byte[] data = new byte[getLength()];
    data[0] = 0;
    data[1] = 6;
    int index = 2;
    int timeout = this.option.getTimeOut();
    if (timeout > 0) {
      int length = "timeout".length();
      System.arraycopy("timeout".getBytes(), 0, data, index, length);
      index += length;
      data[index++] = 0;
      length = String.valueOf(timeout).length();
      System.arraycopy(String.valueOf(timeout).getBytes(), 0, data, index, length);
      index += length;
      data[index++] = 0;
    } 
    int tsize = this.option.gettSize();
    if (tsize > 0) {
      int length = "tsize".length();
      System.arraycopy("tsize".getBytes(), 0, data, index, length);
      index += length;
      data[index++] = 0;
      length = String.valueOf(tsize).length();
      System.arraycopy(String.valueOf(tsize).getBytes(), 0, data, index, length);
      index += length;
      data[index++] = 0;
    } 
    int blksize = this.option.getBlkSize();
    if (blksize > 0) {
      int length = "blksize".length();
      System.arraycopy("blksize".getBytes(), 0, data, index, length);
      index += length;
      data[index++] = 0;
      length = String.valueOf(blksize).length();
      System.arraycopy(String.valueOf(blksize).getBytes(), 0, data, index, length);
      index += length;
      data[index++] = 0;
    } 
    int blockNrIndex = index;
    data[blockNrIndex] = (byte)(getBlockNr() >> 8 & 0xFF);
    data[blockNrIndex + 1] = (byte)(getBlockNr() & 0xFF);
    return data;
  }
}
